@@ -1,36 +1,31 @@
+
 #ifndef APTCACHE_H
 #define APTCACHE_H
 
-#include <QFile>
-#include <QHash>
+#include <QDir>
 #include <QMap>
 
 #include "versionnumber.h"
 
-// Pair of arch names returned by "uname" and corresponding DEB_BUILD_ARCH formats
-static const QHash<QString, QString> arch_names {
-    { "x86_64", "amd64" },
-    { "i686", "i386" },
-    { "armv7l", "armhf" }
-};
+// Pair of arch names returned by QSysInfo::currentCpuArchitecture() and corresponding DEB_BUILD_ARCH formats
+static const QHash<QString, QString> arch_names {{"x86_64", "amd64"}, {"i386", "i386"}, {"arm64", "armhf"}};
 
 class AptCache
 {
 public:
     AptCache();
 
-    void loadCacheFiles();
     QMap<QString, QStringList> getCandidates();
     static QString getArch();
 
 private:
     QMap<QString, QStringList> candidates;
     QString files_content;
-    const QString dir_name = QStringLiteral("/var/lib/apt/lists/");
+    const QDir dir {QStringLiteral("/var/lib/apt/lists/")};
 
-    void parseContent();
     bool readFile(const QString &file_name);
-
+    void loadCacheFiles();
+    void parseContent();
 };
 
 #endif // APTCACHE_H
